# APIAlchemy

API toolkit for Python, modeled after SQLAlchemy

## Installation

```
pip install APIAlchemy
```

## Overview

APIAlchemy provides developers an abstraction layer for consuming web services from the following vendors:
- [AppDynamics](https://docs.appdynamics.com/display/PRO43/Metric+and+Snapshot+API)
- [ExtraHop](https://docs.extrahop.com/7.9/rest-extract-metrics)
- [GitHub](https://developer.github.com/v3/)
- [Prometheus Pushgateway](https://github.com/prometheus/pushgateway)
- [Splunk](https://docs.splunk.com/Documentation/Splunk/8.0.2/RESTUM/RESTusing)

## License

Distributed under the [MIT license](https://opensource.org/licenses/MIT).